@@ -14,6 +14,10 @@ import json
 import types
 
 
+
+
+
+
 class Param(dict):
     '''
 Main class and also the result-dictionary
@@ -40,6 +44,13 @@ s exception is raised if there is an error within the runtime-parameters.
 s os only within the "Process"-function.
         '''
         pass
+    class PathEncoder(json.JSONEncoder):
+        def default(self, z):
+            if isinstance(z, Path) or isinstance(z, PurePath):
+                return (str(z))
+            else:
+                return super().default(z)
+
 #---------------------------------------------
 # Class-local Data
 #---------------------------------------------
@@ -797,7 +808,7 @@ s os only within the "Process"-function.
 
         for o, a in opts:
             if o in self.__ExportList:
-                print(json.dumps(self, sort_keys=True, indent=4))
+                print(json.dumps(self, sort_keys=True, indent=4, cls=self.PathEncoder))
                 sys.exit(0)
 
         for i in self.__Definition.keys():
